# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['eiswarnung']

package_data = \
{'': ['*']}

install_requires = \
['aiohttp>=3.0.0', 'yarl>=1.6.0']

setup_kwargs = {
    'name': 'eiswarnung',
    'version': '1.1.1',
    'description': 'Asynchronous Python client for the Eiswarnung API',
    'long_description': '## Python - Eiswarnung Client\n\n<!-- PROJECT SHIELDS -->\n[![GitHub Release][releases-shield]][releases]\n[![Python Versions][python-versions-shield]][pypi]\n![Project Stage][project-stage-shield]\n![Project Maintenance][maintenance-shield]\n[![License][license-shield]](LICENSE)\n\n[![GitHub Activity][commits-shield]][commits-url]\n[![Forks][forks-shield]][forks-url]\n[![Stargazers][stars-shield]][stars-url]\n[![Issues][issues-shield]][issues-url]\n[![GitHub Last Commit][last-commit-shield]][commits-url]\n\n[![Code Quality][code-quality-shield]][code-quality]\n[![Maintainability][maintainability-shield]][maintainability-url]\n[![Code Coverage][codecov-shield]][codecov-url]\n\n[![Build Status][build-shield]][build-url]\n[![Typing Status][typing-shield]][typing-url]\n\nAsynchronous Python client for the Eiswarnung API.\n\n## About\n\nA python package with which you can read data from [Eiswarnung API][eiswarnung]. This way you know whether it is necessary to scratch your car window the next day, because there is a layer of ice on it. This service comes from Germany but should work in other countries as well.\n\n## Installation\n\n```bash\npip install eiswarnung\n```\n\n## Usage\n\nFor a successful request, you must fill in the `latitude` and `longitude` data and have a valid `API key`, which you can request via [this website][request]. **Note**: there is a limit of 50 requests per day.\n\n```py\nimport asyncio\n\nfrom eiswarnung import Eiswarnung\n\nasync def main():\n    """Show example on getting data from the Eiswarnung API."""\n    async with Eiswarnung(\n        api_key="API_KEY",\n        latitude=49.17,\n        longitude=11.10,\n    ) as client:\n        forecast = await client.forecast()\n        print(forecast)\n        print(client.ratelimit)\n\nif __name__ == "__main__":\n    asyncio.run(main())\n```\n\n## Data\n\nYou can read the following data with this package:\n\n### Forecast\n\n- Request date (datetime)\n- Status ID (int)\n- Forecast Type - in English (str)\n- Forecast Text - in German (str)\n- Forecast City (str)\n- Forecast Date - the next day (datetime)\n\n### Ratelimit\n\n- Call Limit (int)\n- Remaining Calls (int)\n- Retry after (remaining seconds)\n\n## Contributing\n\nThis is an active open-source project. We are always open to people who want to\nuse the code or contribute to it.\n\nWe\'ve set up a separate document for our\n[contribution guidelines](CONTRIBUTING.md).\n\nThank you for being involved! :heart_eyes:\n\n## Setting up development environment\n\nThis Python project is fully managed using the [Poetry][poetry] dependencies\nmanager.\n\nYou need at least:\n\n- Python 3.9+\n- [Poetry][poetry-install]\n\nInstall all packages, including all development requirements:\n\n```bash\npoetry install\n```\n\nPoetry creates by default an virtual environment where it installs all\nnecessary pip packages, to enter or exit the venv run the following commands:\n\n```bash\npoetry shell\nexit\n```\n\nSetup the pre-commit check, you must run this inside the virtual environment:\n\n```bash\npre-commit install\n```\n\n*Now you\'re all set to get started!*\n\nAs this repository uses the [pre-commit][pre-commit] framework, all changes\nare linted and tested with each commit. You can run all checks and tests\nmanually, using the following command:\n\n```bash\npoetry run pre-commit run --all-files\n```\n\nTo run just the Python tests:\n\n```bash\npoetry run pytest\n```\n\n## License\n\nMIT License\n\nCopyright (c) 2021-2022 Klaas Schoute\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the "Software"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.\n\n<!-- PROJECT -->\n[eiswarnung]: https://www.eiswarnung.de\n[request]: https://www.eiswarnung.de/get-api\n\n<!-- MARKDOWN LINKS & IMAGES -->\n[build-shield]: https://github.com/klaasnicolaas/python-eiswarnung/actions/workflows/tests.yaml/badge.svg\n[build-url]: https://github.com/klaasnicolaas/python-eiswarnung/actions/workflows/tests.yaml\n[code-quality-shield]: https://img.shields.io/lgtm/grade/python/g/klaasnicolaas/python-eiswarnung.svg?logo=lgtm&logoWidth=18\n[code-quality]: https://lgtm.com/projects/g/klaasnicolaas/python-eiswarnung/context:python\n[commits-shield]: https://img.shields.io/github/commit-activity/y/klaasnicolaas/python-eiswarnung.svg\n[commits-url]: https://github.com/klaasnicolaas/python-eiswarnung/commits/main\n[codecov-shield]: https://codecov.io/gh/klaasnicolaas/python-eiswarnung/branch/main/graph/badge.svg?token=w0pbSPjFIZ\n[codecov-url]: https://codecov.io/gh/klaasnicolaas/python-eiswarnung\n[forks-shield]: https://img.shields.io/github/forks/klaasnicolaas/python-eiswarnung.svg\n[forks-url]: https://github.com/klaasnicolaas/python-eiswarnung/network/members\n[issues-shield]: https://img.shields.io/github/issues/klaasnicolaas/python-eiswarnung.svg\n[issues-url]: https://github.com/klaasnicolaas/python-eiswarnung/issues\n[license-shield]: https://img.shields.io/github/license/klaasnicolaas/python-eiswarnung.svg\n[last-commit-shield]: https://img.shields.io/github/last-commit/klaasnicolaas/python-eiswarnung.svg\n[maintenance-shield]: https://img.shields.io/maintenance/yes/2022.svg\n[maintainability-shield]: https://api.codeclimate.com/v1/badges/d1c7f7b99ac0225c2e18/maintainability\n[maintainability-url]: https://codeclimate.com/github/klaasnicolaas/python-eiswarnung/maintainability\n[project-stage-shield]: https://img.shields.io/badge/project%20stage-experimental-yellow.svg\n[pypi]: https://pypi.org/project/eiswarnung/\n[python-versions-shield]: https://img.shields.io/pypi/pyversions/eiswarnung\n[typing-shield]: https://github.com/klaasnicolaas/python-eiswarnung/actions/workflows/typing.yaml/badge.svg\n[typing-url]: https://github.com/klaasnicolaas/python-eiswarnung/actions/workflows/typing.yaml\n[releases-shield]: https://img.shields.io/github/release/klaasnicolaas/python-eiswarnung.svg\n[releases]: https://github.com/klaasnicolaas/python-eiswarnung/releases\n[stars-shield]: https://img.shields.io/github/stars/klaasnicolaas/python-eiswarnung.svg\n[stars-url]: https://github.com/klaasnicolaas/python-eiswarnung/stargazers\n\n<!-- Development -->\n[poetry-install]: https://python-poetry.org/docs/#installation\n[poetry]: https://python-poetry.org\n[pre-commit]: https://pre-commit.com\n',
    'author': 'Klaas Schoute',
    'author_email': 'hello@student-techlife.com',
    'maintainer': 'Klaas Schoute',
    'maintainer_email': 'hello@student-techlife.com',
    'url': 'https://github.com/klaasnicolaas/python-eiswarnung',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
